==> plplot-5.12.0.tar.gz: plplot-5.12.0/doc/doxygen/html/search/all_17.js <==
var searchData=
[
  ['w',['w',['../structlweights.html#af40aaef04f119296b33813a0225e00e3',1,'lweights::w()'],['../structTkDev.html#a4c322c4c38c122f4e60fdd8c2296e85d',1,'TkDev::w()']]],
  ['w3d',['w3d',['../classplstream.html#a66f2583f5f748c663508269dd00c1100',1,'plstream']]],
  ['wdxoff',['wdxoff',['../structPLStream.html#a6916b03e47be96ff859874fa15f98fa6',1,'PLStream']]],
  ['wdxscl',['wdxscl',['../structPLStream.html#a36fef6d794ee3daeb1e22fb9552d499a',1,'PLStream']]],
  ['wdyoff',['wdyoff',['../structPLStream.html#a732b5abcb2edb9375695bd9c61e98272',1,'PLStream']]],
  ['wdyscl',['wdyscl',['../structPLStream.html#a1ddb0104b923970d0889e9bcb9820aef',1,'PLStream']]],
  ['weight',['weight',['../structTextSizeInfo.html#afa663f4b7f4f6c2aa0551b8e27d70eef',1,'TextSizeInfo']]],
  ['weightlookup',['weightLookup',['../cairo_8c.html#a8ee4cf3cd65bc4579b564af38718e76e',1,'cairo.c']]],
  ['weights',['weights',['../structlpi.html#a47f09ca005a3a4725ac531d7c1b4a178',1,'lpi::weights()'],['../structnn__weights.html#aa7ff68d9ad8e6499da44ae1ea326f368',1,'nn_weights::weights()'],['../structnnai.html#a864b1bcffbc680629d3c0efeff6d0529',1,'nnai::weights()'],['../structnnpi.html#a5f9dd37ee1ee5fe193df92df14c81875',1,'nnpi::weights()']]],
  ['which_5fclip',['which_clip',['../structSVG.html#ac28d8f81f49562a61c7de7004a0d80a4',1,'SVG']]],
  ['white',['White',['../plstream_8h.html#af38a775b953a654b78d0f13cf899f38bab548046646b36c12aa6ba841de500094',1,'plstream.h']]],
  ['widgetcmd',['widgetCmd',['../structPlPlotter.html#ac8c81c96fb8f23a67e730995fe5ebb9d',1,'PlPlotter']]],
  ['width',['width',['../structTextSizeInfo.html#ab1af6b6260151c04950802322d3daeaf',1,'TextSizeInfo::width()'],['../structplplot_1_1__N4.html#a0f3ef32d5b1784d76004730694a84a8b',1,'plplot::_N4::width()'],['../structPlFrame.html#acc698d3e2671b7ef5a041c04f01dae1c',1,'PlFrame::width()'],['../structTkDev.html#acd6af46bd1c788770c0615962e8119b6',1,'TkDev::width()'],['../structPlPlotter.html#a0242cfa1d0dc49a4f1ffac8d5ae01459',1,'PlPlotter::width()'],['../structTkwDev.html#a11a01cf9504ca9f31486d9508646c8b4',1,'TkwDev::width()'],['../structPLDisplay.html#ae8787ffc7a95b8ebcd7c991e97c1452c',1,'PLDisplay::width()'],['../structPLStream.html#a5ee6732e0c80f6ee27d5588100f07cb7',1,'PLStream::width()'],['../structXwDev.html#a490aa0f52841cfabe6eaf2bdde560989',1,'XwDev::width()'],['../classplstream.html#a7a993bd850c9dc8d7f3fab51b544c778',1,'plstream::width()']]],
  ['widthlock',['widthlock',['../structPLStream.html#a91babbdc474e6a01e602ad5d21c58710',1,'PLStream']]],
  ['widthset',['widthset',['../structPLStream.html#a812c6e5e4d84453944c67784f43b2411',1,'PLStream']]],
  ['wind',['wind',['../classplstream.html#a01d10b709219154e2cd6f7d8920ba95d',1,'plstream']]],
  ['window',['window',['../structTkwDev.html#a143e4e7685a6f27acf861dc819dc2154',1,'TkwDev::window()'],['../structXwDev.html#a18e08f1211cc3a9d9320506f1cb0f251',1,'XwDev::window()']]],
  ['window_5fid',['window_id',['../structPLStream.html#a209b4e2760c7744dcc04912330249551',1,'PLStream']]],
  ['windowxsize',['windowXSize',['../aqt_8c.html#aa18d84ecb5a0965996ad8bbbe7ba7ef2',1,'aqt.c']]],
  ['windowysize',['windowYSize',['../aqt_8c.html#a19833fbb8fb8cf68809de7b4e1373ebb',1,'aqt.c']]],
  ['wingcc_2ec',['wingcc.c',['../wingcc_8c.html',1,'']]],
  ['with_5fcsa',['WITH_CSA',['../plplot__config_8h.html#a890428db053094e0a8d4ea937735cae5',1,'plplot_config.h']]],
  ['wmin',['wmin',['../structnnai.html#aa382af28cedb0b28813e89076c97da20',1,'nnai::wmin()'],['../structnnpi.html#aec08e963c5c5d792cfa191b6b5046fa7',1,'nnpi::wmin()']]],
  ['wmxoff',['wmxoff',['../structPLStream.html#aea4c297c42f3e7e2d3fd21dee421d53a',1,'PLStream']]],
  ['wmxscl',['wmxscl',['../structPLStream.html#ab4124f5acbd397314da02d08f6e29174',1,'PLStream']]],
  ['wmyoff',['wmyoff',['../structPLStream.html#a4b1ed19b6eaa67093322e029692b59b1',1,'PLStream']]],
  ['wmyscl',['wmyscl',['../structPLStream.html#a5a70268fa1d38b34ccf0a3336f58de0a',1,'PLStream']]],
  ['wp',['wp',['../classplplot__double.html#a1e6e7ad2d5490ae8717d2a0ce32690d8',1,'plplot_double::wp()'],['../classplplot__single.html#a197b7deb1258c3fee8e5ebbdf78390b3',1,'plplot_single::wp()']]],
  ['wpointer_5fval',['wPointer_val',['../plcairo__impl_8c.html#a1ec679c5c6e009eebfe203876498265b',1,'plcairo_impl.c']]],
  ['wpxoff',['wpxoff',['../structPLStream.html#a28fc8e7991a0824a135450fca3304966',1,'PLStream']]],
  ['wpxscl',['wpxscl',['../structPLStream.html#a3f07edd33b6774ecc1e1a5df3e7e7072',1,'PLStream']]],
  ['wpyoff',['wpyoff',['../structPLStream.html#afb689ff0653205319126b01be493409f',1,'PLStream']]],
  ['wpyscl',['wpyscl',['../structPLStream.html#a386fb51e8daea7f899c61edd02b589be',1,'PLStream']]],
  ['wr_5fcommand',['wr_command',['../plbuf_8c.html#af4896eb58fe07c91ea761a8a360ba06a',1,'plbuf.c']]],
  ['wr_5fdata',['wr_data',['../plbuf_8c.html#ad513629816f783d949b03054d3a78872',1,'plbuf.c']]],
  ['write_5fhex',['write_hex',['../svg_8c.html#a6bd0dd7904fdd34fb887d3cdfc70511e',1,'svg.c']]],
  ['write_5fto_5fpixmap',['write_to_pixmap',['../structTkwDev.html#a7fa913fd6464fe34fa219fcaaf1f2cbe',1,'TkwDev::write_to_pixmap()'],['../structXwDev.html#ae88d0a77b383c2a295bb2d0ea27b511c',1,'XwDev::write_to_pixmap()']]],
  ['write_5fto_5fstream',['write_to_stream',['../cairo_8c.html#ad9101ac10ca83db3a0ad930aa2d3bf67',1,'cairo.c']]],
  ['write_5fto_5fwindow',['write_to_window',['../structTkwDev.html#a770d670846a19fa7c10cb10e62fee84c',1,'TkwDev::write_to_window()'],['../structXwDev.html#a1f9edf6540ee93db1f82dd87a0a2bb6b',1,'XwDev::write_to_window()']]],
  ['write_5funicode',['write_unicode',['../svg_8c.html#a70c144e4dd3764dc26b900589d0b9040',1,'svg.c']]],
  ['writebufferproc',['writebufferproc',['../plplotcmodulePYTHON__wrap_8c.html#a73671bbcb7aaa4b6221c5df016c52d7f',1,'plplotcmodulePYTHON_wrap.c']]],
  ['writelocation',['writeLocation',['../structMemoryMapHeader.html#a74a1cd16e4e3777dff8460a9bdb3625b',1,'MemoryMapHeader']]],
  ['written',['written',['../structTextSizeInfo.html#abdc25237fa37dbc3af4b2a3fb23f9c6c',1,'TextSizeInfo']]],
  ['wx',['wx',['../structplplot__graphics_1_1plgraphicsin.html#ad3f0d5a7ba1f96326a40c647651b5915',1,'plplot_graphics::plgraphicsin::wx()'],['../structplplot_1_1__N2.html#a935c6c7e9145c1fca94cb1a701b6964a',1,'plplot::_N2::wX()'],['../structPLGraphicsIn.html#a5b265dd393e9731157ecf8bc421bc479',1,'PLGraphicsIn::wX()']]],
  ['wx_5fset_5fbuffer',['wx_set_buffer',['../wxwidgets_8h.html#ab28e3bfaaa5fa87f81c7fa0f8f4b9003',1,'wxwidgets.h']]],
  ['wx_5fset_5fdc',['wx_set_dc',['../wxwidgets_8h.html#a01560f348183083351fa4edc2a5d669f',1,'wxwidgets.h']]],
  ['wxma',['wxma',['../structplplot_1_1__N3.html#a6ddaaba61af2c4b662271fcf40dfbcf3',1,'plplot::_N3::wxma()'],['../structPLWindow.html#ab0553bb8419bd38e6423067bb8eea203',1,'PLWindow::wxma()']]],
  ['wxmax',['wxmax',['../structPLStrip.html#a4b645ccf065628700a5da497eeb65058',1,'PLStrip']]],
  ['wxmi',['wxmi',['../structplplot_1_1__N3.html#ab93302bcc38c067ef896a4a25d4bd6ad',1,'plplot::_N3::wxmi()'],['../structPLWindow.html#a890a5eac4d14c0b40c366e105136fb40',1,'PLWindow::wxmi()']]],
  ['wxmin',['wxmin',['../structPLStrip.html#ab5f92f592afcb4cf7492ffa0eea684cd',1,'PLStrip']]],
  ['wxpldevice',['wxPLDevice',['../classwxPLDevice.html',1,'wxPLDevice'],['../classwxPLDevice.html#af7dc862026548d46a2aa11c2d09f7642',1,'wxPLDevice::wxPLDevice()']]],
  ['wxplplot_5fdraw_5ftext',['wxPLPLOT_DRAW_TEXT',['../wxPLplotstream_8h.html#a99fb83031ce9923c84392b4e92f956b5a377186d2b88dd9178e5b6da729d6647b',1,'wxPLplotstream.h']]],
  ['wxplplot_5fnanosec_2ecpp',['wxPLplot_nanosec.cpp',['../wxPLplot__nanosec_8cpp.html',1,'']]],
  ['wxplplot_5fnanosec_2eh',['wxPLplot_nanosec.h',['../wxPLplot__nanosec_8h.html',1,'']]],
  ['wxplplot_5fnone',['wxPLPLOT_NONE',['../wxPLplotstream_8h.html#a99fb83031ce9923c84392b4e92f956b5a3eaa749477375098b632568c413c4172',1,'wxPLplotstream.h']]],
  ['wxplplot_5fuse_5fhershey_5fsymbols',['wxPLPLOT_USE_HERSHEY_SYMBOLS',['../wxPLplotstream_8h.html#a99fb83031ce9923c84392b4e92f956b5a9132dae93432b16511929bdd47c0386c',1,'wxPLplotstream.h']]],
  ['wxplplotstream',['wxPLplotstream',['../classwxPLplotstream.html',1,'wxPLplotstream'],['../classwxPLplotstream.html#a9a49ebca924e07eaf2c2ee46e2284ddf',1,'wxPLplotstream::wxPLplotstream()'],['../classwxPLplotstream.html#a990615daa9c632a1911597e06d67b07f',1,'wxPLplotstream::wxPLplotstream(wxDC *dc, int width, int height, int style=wxPLPLOT_NONE)']]],
  ['wxplplotstream_2ecpp',['wxPLplotstream.cpp',['../wxPLplotstream_8cpp.html',1,'']]],
  ['wxplplotstream_2eh',['wxPLplotstream.h',['../wxPLplotstream_8h.html',1,'']]],
  ['wxplplotwindow',['wxPLplotwindow',['../classwxPLplotwindow.html',1,'wxPLplotwindow&lt; WXWINDOW &gt;'],['../classwxPLplotwindow.html#a04e9404bd092d669e9eb69d8fcf41699',1,'wxPLplotwindow::wxPLplotwindow()']]],
  ['wxplplotwindow_2eh',['wxPLplotwindow.h',['../wxPLplotwindow_8h.html',1,'']]],
  ['wxwidgets_2ecpp',['wxwidgets.cpp',['../wxwidgets_8cpp.html',1,'']]],
  ['wxwidgets_2eh',['wxwidgets.h',['../wxwidgets_8h.html',1,'']]],
  ['wxwidgets_5fcomms_2ecpp',['wxwidgets_comms.cpp',['../wxwidgets__comms_8cpp.html',1,'']]],
  ['wxwidgets_5fcomms_2eh',['wxwidgets_comms.h',['../wxwidgets__comms_8h.html',1,'']]],
  ['wxwidgets_5fdev_2ecpp',['wxwidgets_dev.cpp',['../wxwidgets__dev_8cpp.html',1,'']]],
  ['wy',['wY',['../structplplot_1_1__N2.html#a1df90e14d71a619b0f913d4a9c36dfff',1,'plplot::_N2::wY()'],['../structPLGraphicsIn.html#a5d79945d06cba50e5e44cc62543312f3',1,'PLGraphicsIn::wY()'],['../structplplot__graphics_1_1plgraphicsin.html#a7cbe9e4c6e109e34c8f188bca3a5cf21',1,'plplot_graphics::plgraphicsin::wy()']]],
  ['wyma',['wyma',['../structplplot_1_1__N3.html#af010eafb3691279a6ceefe4a74d8f511',1,'plplot::_N3::wyma()'],['../structPLWindow.html#aa3aa6d82105e1dba93aea120c7d1cb8e',1,'PLWindow::wyma()']]],
  ['wymax',['wymax',['../structPLStrip.html#a5a960af3e30dc05698c37f437ff0f15d',1,'PLStrip']]],
  ['wymi',['wymi',['../structplplot_1_1__N3.html#a49647d2648e79fda9f0b87637f842aef',1,'plplot::_N3::wymi()'],['../structPLWindow.html#a7b5922ecc2033a58c94224d4985d7a7c',1,'PLWindow::wymi()']]],
  ['wymin',['wymin',['../structPLStrip.html#a895a49fcfcf636dcd819c8a009d6885e',1,'PLStrip']]]
];

==> plplot-5.13.0.tar.gz: plplot-5.13.0/doc/doxygen/html/search/all_17.js <==
var searchData=
[
  ['w',['w',['../structlweights.html#af40aaef04f119296b33813a0225e00e3',1,'lweights::w()'],['../structTkDev.html#a4c322c4c38c122f4e60fdd8c2296e85d',1,'TkDev::w()']]],
  ['w3d',['w3d',['../classplstream.html#a66f2583f5f748c663508269dd00c1100',1,'plstream']]],
  ['wdxoff',['wdxoff',['../structPLStream.html#a6916b03e47be96ff859874fa15f98fa6',1,'PLStream']]],
  ['wdxscl',['wdxscl',['../structPLStream.html#a36fef6d794ee3daeb1e22fb9552d499a',1,'PLStream']]],
  ['wdyoff',['wdyoff',['../structPLStream.html#a732b5abcb2edb9375695bd9c61e98272',1,'PLStream']]],
  ['wdyscl',['wdyscl',['../structPLStream.html#a1ddb0104b923970d0889e9bcb9820aef',1,'PLStream']]],
  ['weight',['weight',['../structTextSizeInfo.html#afa663f4b7f4f6c2aa0551b8e27d70eef',1,'TextSizeInfo']]],
  ['weightlookup',['weightLookup',['../cairo_8c.html#a8ee4cf3cd65bc4579b564af38718e76e',1,'cairo.c']]],
  ['weights',['weights',['../structlpi.html#a47f09ca005a3a4725ac531d7c1b4a178',1,'lpi::weights()'],['../structnn__weights.html#aa7ff68d9ad8e6499da44ae1ea326f368',1,'nn_weights::weights()'],['../structnnai.html#a864b1bcffbc680629d3c0efeff6d0529',1,'nnai::weights()'],['../structnnpi.html#a5f9dd37ee1ee5fe193df92df14c81875',1,'nnpi::weights()']]],
  ['which_5fclip',['which_clip',['../structSVG.html#ac28d8f81f49562a61c7de7004a0d80a4',1,'SVG']]],
  ['white',['White',['../plstream_8h.html#af38a775b953a654b78d0f13cf899f38bab548046646b36c12aa6ba841de500094',1,'plstream.h']]],
  ['widgetcmd',['widgetCmd',['../structPlPlotter.html#ac8c81c96fb8f23a67e730995fe5ebb9d',1,'PlPlotter']]],
  ['width',['width',['../structTextSizeInfo.html#ab1af6b6260151c04950802322d3daeaf',1,'TextSizeInfo::width()'],['../structplplot_1_1__N4.html#a0f3ef32d5b1784d76004730694a84a8b',1,'plplot::_N4::width()'],['../structPlFrame.html#acc698d3e2671b7ef5a041c04f01dae1c',1,'PlFrame::width()'],['../structTkDev.html#acd6af46bd1c788770c0615962e8119b6',1,'TkDev::width()'],['../structPlPlotter.html#a0242cfa1d0dc49a4f1ffac8d5ae01459',1,'PlPlotter::width()'],['../structTkwDev.html#a11a01cf9504ca9f31486d9508646c8b4',1,'TkwDev::width()'],['../structPLDisplay.html#ae8787ffc7a95b8ebcd7c991e97c1452c',1,'PLDisplay::width()'],['../structPLStream.html#a5ee6732e0c80f6ee27d5588100f07cb7',1,'PLStream::width()'],['../structXwDev.html#a490aa0f52841cfabe6eaf2bdde560989',1,'XwDev::width()'],['../classplstream.html#a7a993bd850c9dc8d7f3fab51b544c778',1,'plstream::width()']]],
  ['widthlock',['widthlock',['../structPLStream.html#a91babbdc474e6a01e602ad5d21c58710',1,'PLStream']]],
  ['widthset',['widthset',['../structPLStream.html#a812c6e5e4d84453944c67784f43b2411',1,'PLStream']]],
  ['wind',['wind',['../classplstream.html#a01d10b709219154e2cd6f7d8920ba95d',1,'plstream']]],
  ['window',['window',['../structTkwDev.html#a143e4e7685a6f27acf861dc819dc2154',1,'TkwDev::window()'],['../structXwDev.html#a18e08f1211cc3a9d9320506f1cb0f251',1,'XwDev::window()']]],
  ['window_5fid',['window_id',['../structPLStream.html#a209b4e2760c7744dcc04912330249551',1,'PLStream']]],
  ['windowxsize',['windowXSize',['../aqt_8c.html#aa18d84ecb5a0965996ad8bbbe7ba7ef2',1,'aqt.c']]],
  ['windowysize',['windowYSize',['../aqt_8c.html#a19833fbb8fb8cf68809de7b4e1373ebb',1,'aqt.c']]],
  ['wingcc_2ec',['wingcc.c',['../wingcc_8c.html',1,'']]],
  ['wingdi_2ec',['wingdi.c',['../wingdi_8c.html',1,'']]],
  ['with_5fcsa',['WITH_CSA',['../plplot__config_8h.html#a890428db053094e0a8d4ea937735cae5',1,'plplot_config.h']]],
  ['wmin',['wmin',['../structnnai.html#aa382af28cedb0b28813e89076c97da20',1,'nnai::wmin()'],['../structnnpi.html#aec08e963c5c5d792cfa191b6b5046fa7',1,'nnpi::wmin()']]],
  ['wmxoff',['wmxoff',['../structPLStream.html#aea4c297c42f3e7e2d3fd21dee421d53a',1,'PLStream']]],
  ['wmxscl',['wmxscl',['../structPLStream.html#ab4124f5acbd397314da02d08f6e29174',1,'PLStream']]],
  ['wmyoff',['wmyoff',['../structPLStream.html#a4b1ed19b6eaa67093322e029692b59b1',1,'PLStream']]],
  ['wmyscl',['wmyscl',['../structPLStream.html#a5a70268fa1d38b34ccf0a3336f58de0a',1,'PLStream']]],
  ['wp',['wp',['../classplplot__double.html#a1e6e7ad2d5490ae8717d2a0ce32690d8',1,'plplot_double::wp()'],['../classplplot__single.html#a197b7deb1258c3fee8e5ebbdf78390b3',1,'plplot_single::wp()']]],
  ['wpointer_5fval',['wPointer_val',['../plcairo__impl_8c.html#a1ec679c5c6e009eebfe203876498265b',1,'plcairo_impl.c']]],
  ['wpxoff',['wpxoff',['../structPLStream.html#a28fc8e7991a0824a135450fca3304966',1,'PLStream']]],
  ['wpxscl',['wpxscl',['../structPLStream.html#a3f07edd33b6774ecc1e1a5df3e7e7072',1,'PLStream']]],
  ['wpyoff',['wpyoff',['../structPLStream.html#afb689ff0653205319126b01be493409f',1,'PLStream']]],
  ['wpyscl',['wpyscl',['../structPLStream.html#a386fb51e8daea7f899c61edd02b589be',1,'PLStream']]],
  ['wr_5fcommand',['wr_command',['../plbuf_8c.html#af4896eb58fe07c91ea761a8a360ba06a',1,'plbuf.c']]],
  ['wr_5fdata',['wr_data',['../plbuf_8c.html#ad513629816f783d949b03054d3a78872',1,'plbuf.c']]],
  ['write_5fhex',['write_hex',['../svg_8c.html#a6bd0dd7904fdd34fb887d3cdfc70511e',1,'svg.c']]],
  ['write_5fto_5fpixmap',['write_to_pixmap',['../structTkwDev.html#a7fa913fd6464fe34fa219fcaaf1f2cbe',1,'TkwDev::write_to_pixmap()'],['../structXwDev.html#ae88d0a77b383c2a295bb2d0ea27b511c',1,'XwDev::write_to_pixmap()']]],
  ['write_5fto_5fstream',['write_to_stream',['../cairo_8c.html#ad9101ac10ca83db3a0ad930aa2d3bf67',1,'cairo.c']]],
  ['write_5fto_5fwindow',['write_to_window',['../structTkwDev.html#a770d670846a19fa7c10cb10e62fee84c',1,'TkwDev::write_to_window()'],['../structXwDev.html#a1f9edf6540ee93db1f82dd87a0a2bb6b',1,'XwDev::write_to_window()']]],
  ['write_5funicode',['write_unicode',['../svg_8c.html#a70c144e4dd3764dc26b900589d0b9040',1,'svg.c']]],
  ['writebufferproc',['writebufferproc',['../plplotcPYTHON__wrap_8c.html#a73671bbcb7aaa4b6221c5df016c52d7f',1,'plplotcPYTHON_wrap.c']]],
  ['writelocation',['writeLocation',['../structMemoryMapHeader.html#a74a1cd16e4e3777dff8460a9bdb3625b',1,'MemoryMapHeader']]],
  ['written',['written',['../structTextSizeInfo.html#abdc25237fa37dbc3af4b2a3fb23f9c6c',1,'TextSizeInfo']]],
  ['wx',['wx',['../structplplot__graphics_1_1plgraphicsin.html#ad3f0d5a7ba1f96326a40c647651b5915',1,'plplot_graphics::plgraphicsin::wx()'],['../structplplot_1_1__N2.html#a935c6c7e9145c1fca94cb1a701b6964a',1,'plplot::_N2::wX()'],['../structPLGraphicsIn.html#a5b265dd393e9731157ecf8bc421bc479',1,'PLGraphicsIn::wX()']]],
  ['wx_5fset_5fbuffer',['wx_set_buffer',['../wxwidgets_8h.html#ab28e3bfaaa5fa87f81c7fa0f8f4b9003',1,'wxwidgets.h']]],
  ['wx_5fset_5fdc',['wx_set_dc',['../wxwidgets_8h.html#a01560f348183083351fa4edc2a5d669f',1,'wxwidgets.h']]],
  ['wxma',['wxma',['../structplplot_1_1__N3.html#a6ddaaba61af2c4b662271fcf40dfbcf3',1,'plplot::_N3::wxma()'],['../structPLWindow.html#ab0553bb8419bd38e6423067bb8eea203',1,'PLWindow::wxma()']]],
  ['wxmax',['wxmax',['../structPLStrip.html#a4b645ccf065628700a5da497eeb65058',1,'PLStrip']]],
  ['wxmi',['wxmi',['../structplplot_1_1__N3.html#ab93302bcc38c067ef896a4a25d4bd6ad',1,'plplot::_N3::wxmi()'],['../structPLWindow.html#a890a5eac4d14c0b40c366e105136fb40',1,'PLWindow::wxmi()']]],
  ['wxmin',['wxmin',['../structPLStrip.html#ab5f92f592afcb4cf7492ffa0eea684cd',1,'PLStrip']]],
  ['wxpldevice',['wxPLDevice',['../classwxPLDevice.html',1,'wxPLDevice'],['../classwxPLDevice.html#af7dc862026548d46a2aa11c2d09f7642',1,'wxPLDevice::wxPLDevice()']]],
  ['wxplplot_5fdraw_5ftext',['wxPLPLOT_DRAW_TEXT',['../wxPLplotstream_8h.html#a99fb83031ce9923c84392b4e92f956b5a377186d2b88dd9178e5b6da729d6647b',1,'wxPLplotstream.h']]],
  ['wxplplot_5fnanosec_2ecpp',['wxPLplot_nanosec.cpp',['../wxPLplot__nanosec_8cpp.html',1,'']]],
  ['wxplplot_5fnanosec_2eh',['wxPLplot_nanosec.h',['../wxPLplot__nanosec_8h.html',1,'']]],
  ['wxplplot_5fnone',['wxPLPLOT_NONE',['../wxPLplotstream_8h.html#a99fb83031ce9923c84392b4e92f956b5a3eaa749477375098b632568c413c4172',1,'wxPLplotstream.h']]],
  ['wxplplot_5fuse_5fhershey_5fsymbols',['wxPLPLOT_USE_HERSHEY_SYMBOLS',['../wxPLplotstream_8h.html#a99fb83031ce9923c84392b4e92f956b5a9132dae93432b16511929bdd47c0386c',1,'wxPLplotstream.h']]],
  ['wxplplotstream',['wxPLplotstream',['../classwxPLplotstream.html',1,'wxPLplotstream'],['../classwxPLplotstream.html#a9a49ebca924e07eaf2c2ee46e2284ddf',1,'wxPLplotstream::wxPLplotstream()'],['../classwxPLplotstream.html#a990615daa9c632a1911597e06d67b07f',1,'wxPLplotstream::wxPLplotstream(wxDC *dc, int width, int height, int style=wxPLPLOT_NONE)']]],
  ['wxplplotstream_2ecpp',['wxPLplotstream.cpp',['../wxPLplotstream_8cpp.html',1,'']]],
  ['wxplplotstream_2eh',['wxPLplotstream.h',['../wxPLplotstream_8h.html',1,'']]],
  ['wxplplotwindow',['wxPLplotwindow',['../classwxPLplotwindow.html',1,'wxPLplotwindow&lt; WXWINDOW &gt;'],['../classwxPLplotwindow.html#a04e9404bd092d669e9eb69d8fcf41699',1,'wxPLplotwindow::wxPLplotwindow()']]],
  ['wxplplotwindow_2eh',['wxPLplotwindow.h',['../wxPLplotwindow_8h.html',1,'']]],
  ['wxwidgets_2ecpp',['wxwidgets.cpp',['../wxwidgets_8cpp.html',1,'']]],
  ['wxwidgets_2eh',['wxwidgets.h',['../wxwidgets_8h.html',1,'']]],
  ['wxwidgets_5fcomms_2ecpp',['wxwidgets_comms.cpp',['../wxwidgets__comms_8cpp.html',1,'']]],
  ['wxwidgets_5fcomms_2eh',['wxwidgets_comms.h',['../wxwidgets__comms_8h.html',1,'']]],
  ['wxwidgets_5fdev_2ecpp',['wxwidgets_dev.cpp',['../wxwidgets__dev_8cpp.html',1,'']]],
  ['wy',['wY',['../structplplot_1_1__N2.html#a1df90e14d71a619b0f913d4a9c36dfff',1,'plplot::_N2::wY()'],['../structPLGraphicsIn.html#a5d79945d06cba50e5e44cc62543312f3',1,'PLGraphicsIn::wY()'],['../structplplot__graphics_1_1plgraphicsin.html#a7cbe9e4c6e109e34c8f188bca3a5cf21',1,'plplot_graphics::plgraphicsin::wy()']]],
  ['wyma',['wyma',['../structplplot_1_1__N3.html#af010eafb3691279a6ceefe4a74d8f511',1,'plplot::_N3::wyma()'],['../structPLWindow.html#aa3aa6d82105e1dba93aea120c7d1cb8e',1,'PLWindow::wyma()']]],
  ['wymax',['wymax',['../structPLStrip.html#a5a960af3e30dc05698c37f437ff0f15d',1,'PLStrip']]],
  ['wymi',['wymi',['../structplplot_1_1__N3.html#a49647d2648e79fda9f0b87637f842aef',1,'plplot::_N3::wymi()'],['../structPLWindow.html#a7b5922ecc2033a58c94224d4985d7a7c',1,'PLWindow::wymi()']]],
  ['wymin',['wymin',['../structPLStrip.html#a895a49fcfcf636dcd819c8a009d6885e',1,'PLStrip']]]
];
